"""This is a collection of tools created to help geoprocessing.
In general, users should simply type "import gptools" in their
scripts to gain access to the functionality.

Requires xlrd and dbfpy to be installed.

The organization of the tools are as follows:

gptools
    calculate
        distanceVicenty()        Calculate distance using Vicenty formula
        distanceGreatCircle()    Calculate distance using Great Circle formula
    convert
        fc
            pointsToLines()          Convert point feature class to line
            pointsToPolygons()       Convert point feature class to polygon
            multipointsToPoints()    Convert multipoint feature class to point
            pointsToMultiPoints()    Convert point feature class to multipoint
            linesToPoints()          Convert line feature class to point
            linesToMultiPoints()     Convert line feature class to multipoint
            polygonsToPoints()       Convert polygon feature class to point
            polygonsToMultipoints()  Convert polygon feature class to multipoint
            kmlToFC()                Convert a KML file to a feature class
            fcToKML()                Convert a feature class to a KML file
        table
            xlsToDbf()               Convert an Excel sheet to DBF
        units
            metersToFeet()           Convert meters to feet
            metersToUSFeet()         Convert meters to US feet
            metersToMiles()          Convert meters to miles
            feetToMeters()           Convert feet to meters
            usFeetToMeters()         Convert US feet to meters
            feetToMiles()            Convert feet to miles
            meters2ToFeet2()         Convert square meters to square feet
            feet2ToMeters2()         Convert square feet to square meters
            meters2ToMiles2()        Convert square meters to square miles
            miles2ToMeters2()        Convert square miles to square meters
            degreesToRadians()       Convert degrees to radians
            radiansToDegrees()       Convert radians to degrees
    utils
        getGP()                      Get a geoprocessing object (either new or existing)
"""

__license__ = 'MIT'
__author__ = 'Michalis Avraam'
__copyright__ = '2010'

# Import packages
import utils
import convert

# Import files
import calculate

__all__ = ["utils", "convert"]


