"""Various util functions, part of gptools."""

import sys

GEOPROCESSOR = None

def getGP():
    """Safely returns the geoprocessor object, by either finding it
    in the stack or initializing it as needed.
    NOTE: Only searches for an initialized geoprocessor in the main program"""
    global GEOPROCESSOR
    # Check if the module initialized the geoprocessor
    if type(GEOPROCESSOR).__name__ == 'geoprocessing object':
            return GEOPROCESSOR  
    # Check if the arcgisscripting module was loaded
    if "arcgisscripting" not in sys.modules:
        # The arcgisscripting module was never loaded Try to load it. 
        try:
            import arcgisscripting
        except ImportError, errorDetail:
            sys.exit("Error loading arcgisscriping. Is ArcGIS installed?\n" + errorDetail)
        # Try to create a geoprocessor instantiation
        try:
            gp = arcgisscripting.create(9.3)
        except:
            sys.exit("Error creating geoprocessor object. Exiting\n" + str(sys.exc_info()))
        # Return the geoprocessor instance
        GEOPROCESSOR = gp
        return gp
    else:
        # arcgisscripting was loaded. Is the geoprocessor instantiated?
        # Get the global variables
        globalVars = vars(sys.modules["__main__"])
        for item, key in globalVars.iteritems():
            # Loop through global variables, ignore internals
            if not item.startswith("__"):
                # Check the type of the variable
                if type(globalVars[item]).__name__ == 'geoprocessing object':
                    # If the variable is the geoprocessor, return it
                    GEOPROCESSOR = globalVars[item]
                    return globalVars[item]
        # If we are here, the module is loaded but no gp instantiated
        # Try to create a geoprocessor instantiation
        try:
            print "arcgisscripting loaded but not instantiated. Instantiating now..."
            gp = sys.modules["arcgisscripting"].create(9.3)
        except:
            sys.exit("Error creating geoprocessor object. Exiting\n" + str(sys.exc_info()))
        # Return the geoprocessor instance and save
        GEOPROCESSOR = gp
        return gp
    